import {
	options
} from '@/http/config.js';
import Request from '@/utils/luch-request/index.js';
const http = new Request(options);
http.interceptors.request.use((config) => { // 可使用async await 做异步操作
	// 假设有token值需要在头部需要携带
	let token = uni.getStorageSync('token');
	if (token) {
		config.header['Authorization'] = 'Bearer ' + token;
	}

	// #ifndef H5
	let url = config.url
	if (process.env.NODE_ENV == 'development' && !url.startsWith("http")) {
		config.url = url
	}
	// #endif

	return config
}, config => { // 可使用async await 做异步操作
	return Promise.reject(config)
})
http.interceptors.response.use((response) => {
	// 若有数据返回则通过
	if (response.data.access_token || response.data.key) {
		return response.data
	}
	// 服务端返回的状态码不等于200，则reject()
	if (response.data.code && response.data.code !== 200) {
		setTimeout(() => {
			uni.showToast({
				title: response.data.msg,
				icon: 'none'
			});
		})
		return Promise.reject(response);
	}
	return response.data;
}, (response) => {
	/*  对响应错误做点什么 （statusCode !== 200）*/
	setTimeout(() => {
		uni.showToast({
			title: response.data.msg || response.data.error_description || '网络错误',
			icon: 'none'
		});
	})

	if (response.statusCode == 401) {
		const pages = getCurrentPages()
		const currentPage = pages[pages.length - 1]
		uni.redirectTo({
			url: `/pages/login?redirect=/${currentPage.route}`
		})
	}
	return Promise.reject(response)
})
/**
 * @description 解密 JWT token 的信息
 * @param token jwt token 字符串
 * @returns <any>object
 */
function decryptJWT(token) {
	token = token.replace(/_/g, "/").replace(/-/g, "+");
	const json = decodeURIComponent(escape(window.atob(token.split(".")[1])));
	return JSON.parse(json);
}

/**
 * @description 将 JWT 时间戳转换成 Date，主要针对 `exp`，`iat`，`nbf`
 * @param timestamp 时间戳
 * @returns Date 对象
 */
function getJWTDate(timestamp) {
	return new Date(timestamp * 1000);
}
export default http;